==> dav1d-doc-1.0.0-1-x86_64.pkg.tar.zst: usr/share/doc/dav1d/html/search/functions_0.js <==
var searchData=
[
  ['dav1d_5fapply_5fgrain_0',['dav1d_apply_grain',['../dav1d_8h.html#ad19b315abdff30e72ac3ab276a5ece46',1,'dav1d.h']]],
  ['dav1d_5fclose_1',['dav1d_close',['../dav1d_8h.html#a57c5dfd3c50e65b48ab9ed65e0f4fd6b',1,'dav1d.h']]],
  ['dav1d_5fdata_5fcreate_2',['dav1d_data_create',['../data_8h.html#afd8aa2f4f1382282cb4c267d13ecb0ed',1,'data.h']]],
  ['dav1d_5fdata_5fprops_5funref_3',['dav1d_data_props_unref',['../common_8h.html#ac02c9e1a5fdac32be18aa968b3f2932f',1,'common.h']]],
  ['dav1d_5fdata_5funref_4',['dav1d_data_unref',['../data_8h.html#a74bd791474aa3b9fb4a5b5bc55e7042a',1,'data.h']]],
  ['dav1d_5fdata_5fwrap_5',['dav1d_data_wrap',['../data_8h.html#a1a5285aab3d2d355a35c33079de69dbd',1,'data.h']]],
  ['dav1d_5fdata_5fwrap_5fuser_5fdata_6',['dav1d_data_wrap_user_data',['../data_8h.html#a27a5e69c0b9c7def7beeb9119404ca2b',1,'data.h']]],
  ['dav1d_5fdefault_5fsettings_7',['dav1d_default_settings',['../dav1d_8h.html#aae458711df16114c733da2e3c222488c',1,'dav1d.h']]],
  ['dav1d_5fflush_8',['dav1d_flush',['../dav1d_8h.html#ab4e8543c6f83d59efbad33f14eae1f22',1,'dav1d.h']]],
  ['dav1d_5fget_5fdecode_5ferror_5fdata_5fprops_9',['dav1d_get_decode_error_data_props',['../dav1d_8h.html#aff844ed31b5e1f8249638154103cca29',1,'dav1d.h']]],
  ['dav1d_5fget_5fevent_5fflags_10',['dav1d_get_event_flags',['../dav1d_8h.html#a989bb8be71d5a2d59e57c03b1fe9e823',1,'dav1d.h']]],
  ['dav1d_5fget_5fpicture_11',['dav1d_get_picture',['../dav1d_8h.html#a231e6aa679d5e46fcdac7546f03a6506',1,'dav1d.h']]],
  ['dav1d_5fopen_12',['dav1d_open',['../dav1d_8h.html#a6cf42b3e954f16afc527e0dadbb14099',1,'dav1d.h']]],
  ['dav1d_5fparse_5fsequence_5fheader_13',['dav1d_parse_sequence_header',['../dav1d_8h.html#a97efb0ec561878ae0921fadf27b7f5cb',1,'dav1d.h']]],
  ['dav1d_5fpicture_5funref_14',['dav1d_picture_unref',['../picture_8h.html#a51be95661e4212a556a531bb9b3c70cf',1,'picture.h']]],
  ['dav1d_5fsend_5fdata_15',['dav1d_send_data',['../dav1d_8h.html#ab2e81b8a272d07ba3f80fb66b980b874',1,'dav1d.h']]],
  ['dav1d_5fversion_16',['dav1d_version',['../dav1d_8h.html#a9ec06f24b3798b1123dc7d3e468bbac4',1,'dav1d.h']]]
];

==> dav1d-doc-1.1.0-1-x86_64.pkg.tar.zst: usr/share/doc/dav1d/html/search/functions_0.js <==
var searchData=
[
  ['dav1d_5fapply_5fgrain_0',['dav1d_apply_grain',['../dav1d_8h.html#ad19b315abdff30e72ac3ab276a5ece46',1,'dav1d.h']]],
  ['dav1d_5fclose_1',['dav1d_close',['../dav1d_8h.html#a57c5dfd3c50e65b48ab9ed65e0f4fd6b',1,'dav1d.h']]],
  ['dav1d_5fdata_5fcreate_2',['dav1d_data_create',['../data_8h.html#afd8aa2f4f1382282cb4c267d13ecb0ed',1,'data.h']]],
  ['dav1d_5fdata_5fprops_5funref_3',['dav1d_data_props_unref',['../common_8h.html#ac02c9e1a5fdac32be18aa968b3f2932f',1,'common.h']]],
  ['dav1d_5fdata_5funref_4',['dav1d_data_unref',['../data_8h.html#a74bd791474aa3b9fb4a5b5bc55e7042a',1,'data.h']]],
  ['dav1d_5fdata_5fwrap_5',['dav1d_data_wrap',['../data_8h.html#a1a5285aab3d2d355a35c33079de69dbd',1,'data.h']]],
  ['dav1d_5fdata_5fwrap_5fuser_5fdata_6',['dav1d_data_wrap_user_data',['../data_8h.html#a27a5e69c0b9c7def7beeb9119404ca2b',1,'data.h']]],
  ['dav1d_5fdefault_5fsettings_7',['dav1d_default_settings',['../dav1d_8h.html#aae458711df16114c733da2e3c222488c',1,'dav1d.h']]],
  ['dav1d_5fflush_8',['dav1d_flush',['../dav1d_8h.html#ab4e8543c6f83d59efbad33f14eae1f22',1,'dav1d.h']]],
  ['dav1d_5fget_5fdecode_5ferror_5fdata_5fprops_9',['dav1d_get_decode_error_data_props',['../dav1d_8h.html#aff844ed31b5e1f8249638154103cca29',1,'dav1d.h']]],
  ['dav1d_5fget_5fevent_5fflags_10',['dav1d_get_event_flags',['../dav1d_8h.html#a989bb8be71d5a2d59e57c03b1fe9e823',1,'dav1d.h']]],
  ['dav1d_5fget_5fframe_5fdelay_11',['dav1d_get_frame_delay',['../dav1d_8h.html#afced59c1dd6ae454f5800bcd243157e8',1,'dav1d.h']]],
  ['dav1d_5fget_5fpicture_12',['dav1d_get_picture',['../dav1d_8h.html#a231e6aa679d5e46fcdac7546f03a6506',1,'dav1d.h']]],
  ['dav1d_5fopen_13',['dav1d_open',['../dav1d_8h.html#a6cf42b3e954f16afc527e0dadbb14099',1,'dav1d.h']]],
  ['dav1d_5fparse_5fsequence_5fheader_14',['dav1d_parse_sequence_header',['../dav1d_8h.html#a97efb0ec561878ae0921fadf27b7f5cb',1,'dav1d.h']]],
  ['dav1d_5fpicture_5funref_15',['dav1d_picture_unref',['../picture_8h.html#a51be95661e4212a556a531bb9b3c70cf',1,'picture.h']]],
  ['dav1d_5fsend_5fdata_16',['dav1d_send_data',['../dav1d_8h.html#ab2e81b8a272d07ba3f80fb66b980b874',1,'dav1d.h']]],
  ['dav1d_5fversion_17',['dav1d_version',['../dav1d_8h.html#a9ec06f24b3798b1123dc7d3e468bbac4',1,'dav1d.h']]]
];
